
from .velkoz import(
        set_api_key,
        set_ddragon,
        get_account,
        get_summoner,
        get_match_list,
        get_match,
        get_all_masteries,
        get_champion_mastery,
        get_top_masteries,
        get_masteryscore,
        get_champion,
        get_champ_image,
        get_champName_by_key

        )

from .settings import *



from .tentacles import (
        AccountApi,
        ChampionMasteryApi,
        RiotApiService,
        api_key,
        MatchApi,
        SummonerApi
        )

from .eye import (
        Summoner,
        Match,
        Participant,
        Account
        )
from .data import(
        DdragonRequest,
        Champion,
        RiotJson,
        Skins

        )
